@@ -30,6 +30,7 @@ def validate_sampler(sampler_data):
         SAMPLER_SCHEMA[sampler_data['type']]
         )
 
+
 PARAMETER_SCHEMA = {
     'oneOf': [
         {
@@ -47,15 +48,15 @@ PARAMETER_SCHEMA = {
             },
             # Require defining each field once.
             'allOf': [
-                {'oneOf':[
+                {'oneOf': [
                     {'required': ['min']},
                     {'required': ['start']},
                 ]},
-                {'oneOf':[
+                {'oneOf': [
                     {'required': ['max']},
                     {'required': ['stop']},
                 ]},
-                {'oneOf':[
+                {'oneOf': [
                     {'required': ['step']},
                     {'required': ['num_points']},
                 ]},
@@ -64,8 +65,10 @@ PARAMETER_SCHEMA = {
         {
             'type': 'string',
             'anyOf': [
-                {'pattern': r'\[[0-9]*\.?[0-9]+:[0-9]*\.?[0-9]+:[0-9]*\.?[0-9]+\]'},
-                {'pattern': r'[0-9]*\.?[0-9]+ to [0-9]*\.?[0-9]+ by [0-9]*\.?[0-9]+'},
+                {'pattern': (r'\[[0-9]*\.?[0-9]+:[0-9]*\.?'
+                             r'[0-9]+:[0-9]*\.?[0-9]+\]')},
+                {'pattern': (r'[0-9]*\.?[0-9]+ to [0-9]*\.?'
+                             r'[0-9]+ by [0-9]*\.?[0-9]+')},
             ]
         }
     ]
@@ -86,6 +89,7 @@ LIST_SCHEMA = {
     'required': ['type'],
 }
 
+
 # Built-in schema
 COLUMN_LIST_SCHEMA = {
     'type': 'object',
@@ -148,6 +152,18 @@ RANDOM_SCHEMA = {
 
 BEST_CANDIDATE_SCHEMA = RANDOM_SCHEMA
 
+
+UQPIPELINE_SCHEMA = {
+    'type': 'object',
+    'properties': {
+        'type': {'type': 'string'},
+        'uq_samples': {'type': 'string'},
+        'uq_points': {'type': 'string'},
+        'uq_variables': {'type': 'string'},
+        'uq_code': {'type': 'string'},
+    },
+    'required': ['type', 'uq_code'],
+}
 SAMPLER_SCHEMA = {
     'list': LIST_SCHEMA,
     'column_list': COLUMN_LIST_SCHEMA,
@@ -155,5 +171,6 @@ SAMPLER_SCHEMA = {
     'csv': CSV_SCHEMA,
     'custom': CUSTOM_SCHEMA,
     'random': RANDOM_SCHEMA,
-    'best_candidate': BEST_CANDIDATE_SCHEMA
+    'best_candidate': BEST_CANDIDATE_SCHEMA,
+    'uqpipeline': UQPIPELINE_SCHEMA
 }
